

set -ex



echo linux_aarch64
echo aarch64
${CC} ${CFLAGS} -Wall tests/aligned_alloc.c -c -o c_aligned.o -v
${CC} ${LDFLAGS} c_aligned.o -o c_aligned
./c_aligned
test -z "${CONDA_BUILD_SYSROOT+x}" && echo "CONDA_BUILD_SYSROOT is not set" && exit 1
test -d ${CONDA_BUILD_SYSROOT} || exit 1
exit 0
